@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: views.py 11646 2019-07-01 01:31:33Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
-# $Revision: 11616 $
+# $Date: 2019-07-01 09:31:33 +0800 (週一, 01 七月 2019) $
+# $Revision: 11646 $
 
 import re
 import time
@@ -30,7 +30,7 @@ from django.core.urlresolvers import reverse
 from django.shortcuts import HttpResponse
 from django.utils.translation import ugettext as _
 from django.core.cache import cache
-from django.shortcuts import render_to_response, get_object_or_404
+from django.shortcuts import render_to_response, get_object_or_404, render
 from django.template import RequestContext
 
 from Iuppiter.extension.views import jsonpCallback
@@ -58,8 +58,7 @@ def _getDomain():
 try:
     _domain = _getDomain()
 except Exception as e:
-    # Migrate...?
-    print(str(e))
+    # Migrate 時會顯示 error
     _domain = ''
 
 AWS_ACCESS_KEY_ID = settings.AWS_ACCESS_KEY_ID
@@ -766,8 +765,7 @@ def resendErrorContact(request, newsletterId):
     else:
         context['information'] = _('All errors have been resent')
 
-    return render_to_response('NewsletterHistoric.html',
-                              context, context_instance=RequestContext(request))
+    return render(request, 'NewsletterHistoric.html', context)
 
 def viewErrorDetails(request, slug, contactMailingStatusId):
     """
@@ -804,8 +802,4 @@ def viewErrorDetails(request, slug, contactMailingStatusId):
         'app_label': opts.app_label,
         'content': content
     }
-    return render_to_response(
-        'NewsletterHistoricErrorDetail.html',
-        context,
-        context_instance=RequestContext(request)
-    )
\ No newline at end of file
+    return render(request, 'NewsletterHistoricErrorDetail.html', context)
\ No newline at end of file
