@@ -53,5 +53,6 @@ def cleanFields(self, *args, **kwargs):
     if self.pk is None:
         self.content = replaceNewsletterKeyword(self.content)
 
-Newsletter.clean = types.MethodType(cleanFields, None, Newsletter)
+#Newsletter.clean = types.MethodType(cleanFields, None, Newsletter)
+Newsletter.clean = cleanFields
 
