@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: views.py 11648 2019-07-02 09:11:40Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
-# $Revision: 11616 $
+# $Date: 2019-07-02 17:11:40 +0800 (週二, 02 七月 2019) $
+# $Revision: 11648 $
 
 import base64
 from datetime import datetime
@@ -60,10 +60,10 @@ logger = createDebugLogger('TheophrastusIntegrationApi', settings.API_LOG)
 
 class TokenGenerator(object):
     def __init__(self, secretKey):
-        self.encryptor = Encryptor(str(secretKey))
+        self.encryptor = Encryptor(secretKey.encode())
 
     def getToken(self, content):
-        return base64.urlsafe_b64encode(self.encryptor.encrypt(str(content)))
+        return base64.urlsafe_b64encode(self.encryptor.encrypt(content.encode()))
 
     def getContent(self, token):
         return self.encryptor.decrypt(base64.urlsafe_b64decode(token))
@@ -158,11 +158,11 @@ def login(request):
                     generator = TokenGenerator(username)
                     t = datetime.now().strftime('%Y%m%d%H%M%S')
                     token = generator.getToken('%s|%d' % (t, app.id))
-                    token = '%s|%s' % (username, token)
+                    token = '%s|%s' % (username, token.decode())
                     # 2.
                     generator = TokenGenerator(SECRET_KEY)
                     token = generator.getToken(token)
-                    return {'token': token}
+                    return {'token': token.decode()}
                 else:
                     raise LoginException("The password is valid, but the "
                                          "account has been disabled!")
@@ -187,12 +187,12 @@ def getAppId(token):
         generator = TokenGenerator(SECRET_KEY)
         token = generator.getContent(str(token))
         # 2.
-        _token = token.split('|')
+        _token = token.decode().split('|')
         username = _token.pop(0)
         generator = TokenGenerator(username)
         content = generator.getContent('|'.join(_token))
 
-        _content = content.split('|')
+        _content = content.decode().split('|')
         appId = _content[-1]
         return int(appId)
     except Exception as e:
@@ -290,7 +290,7 @@ def mail(request):
 
             _postData = parse_qsl(request.body, True)
             for (_k, _d) in _postData:
-                _k = unquote(_k)
+                _k = unquote(_k.decode())
                 if (_k.startswith('attachmentContent')) or (
                     _k.startswith('attachmentName')) or (
                     _k.startswith('attachmentType')):
