@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 11555 2019-05-16 07:37:39Z Andy $
+# $Id: StatisticsHandler.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-05-16 15:37:39 +0800 (週四, 16 五月 2019) $
-# $Revision: 11555 $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
 from datetime import timedelta, datetime
 
@@ -74,7 +74,7 @@ def getDateRange(startDate, endDate):
     """
     Get range of dates.
     """
-    if isinstance(startDate, str) or isinstance(startDate, unicode):
+    if isinstance(startDate, str) or isinstance(startDate, type(b'')):
         if startDate != "NaN":
             startDate = datetime.strptime(startDate, '%Y-%m-%d %H:%M:%S')
     if isinstance(endDate, str):
@@ -702,12 +702,12 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     deltaDays = None
 
     startDate = reqestGetData.get('startDate', None)
-    if isinstance(startDate, str) or isinstance(startDate, unicode):
+    if isinstance(startDate, str) or isinstance(startDate, type(b'')):
         if startDate != "NaN":
             startDate = datetime.strptime(startDate, '%Y/%m/%d')
 
     endDate = reqestGetData.get('endDate', None)
-    if isinstance(endDate, str) or isinstance(endDate, unicode):
+    if isinstance(endDate, str) or isinstance(endDate, type(b'')):
         if endDate != "NaN":
             endDate = datetime.strptime(endDate, '%Y/%m/%d')
 
@@ -771,7 +771,7 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
 
     _STATUS_NAMES = []
     for i in STATUS_NAMES:
-        _STATUS_NAMES.append(unicode(i))
+        _STATUS_NAMES.append(str(i))
 
     response = {
         'context': {
@@ -849,7 +849,7 @@ def getStatisticsTotalRateData(reqestGetData, subscriberCount,
 
     _STATUS_NAMES = []
     for i in STATUS_NAMES:
-        _STATUS_NAMES.append(unicode(i))
+        _STATUS_NAMES.append(str(i))
 
     response = {
         'context': dict(rates),
