@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10838 2018-03-12 10:54:45Z David $
+# $Id: urls.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,16 +11,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-12 18:54:45 +0800 (週一, 12 三月 2018) $
-# $Revision: 10838 $
+# $Author: Andy $
+# $Date: 2019-06-07 10:15:46 +0800 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
-from django.conf.urls import url, include, patterns
+from django.conf.urls import url, include
 from django.conf import settings
 
 from Theophrastus import views
 
-urlpatterns = patterns('', 
+urlpatterns = [
     # django-selectable.
     url(r'^newsletters/selectable/', include('selectable.urls')),
     url(r'^tracking/historic/(?P<slug>[-\w]+)/$', views.viewNewsletterHistoric,
@@ -28,7 +28,7 @@ urlpatterns = patterns('',
     
     # api 統合其他 app 的 api url
     url(r'^api/', include('Theophrastus.api.urls')),
-)
+]
 
 # Newsletter_extension
 if 'Theophrastus.newsletter_extension' in settings.INSTALLED_APPS:
